@@ -38,6 +38,7 @@ int g_key=0;
 int g_playmode=0;
 int g_switch = 0;
 long g_nextid=0;
+bool g_debug= TRUE;
 
 Glcontrol    *g_gl=NULL;
 QString g_prjpath;
@@ -46,6 +47,7 @@ QString g_editor;
 // Catalog
 QString g_3dcatalogpath;
 QString g_scriptcatalogpath;
+int g_3dcatalogkategorie=0;
 QString g_soundcatalogpath;
 QString g_shadercatalogpath;
 QString g_physikcatalogpath;
