@@ -35,6 +35,7 @@ extern int g_key;
 extern int g_playmode;
 extern int g_switch;
 extern long g_nextid;
+extern bool g_debug;
 
 extern class aStar *gastar;
 extern class netclient    *g_client;
@@ -44,6 +45,7 @@ extern class FolderListItem * g_switchScene;
 extern class QString g_prjpath;
 extern class QString g_3dcatalogpath;
 extern class QString g_scriptcatalogpath;
+extern int g_3dcatalogkategorie;
 extern class QString g_soundcatalogpath;
 extern class QString g_shadercatalogpath;
 extern class QString g_physikcatalogpath;
