@@ -35,12 +35,15 @@ extern int g_key;
 extern int g_playmode;
 extern int g_switch;
 extern long g_nextid;
+extern bool g_debug;
 
 extern class aStar *gastar;
 extern class netclient    *g_client;
 extern class Glcontrol    *g_gl;
 extern class FolderListItem *g_tmpItem;
 extern class FolderListItem * g_switchScene;
+extern QString g_3dcatalogpath;
+extern int g_3dcatalogkategorie;
 extern class QString g_prjpath;
 extern class QString g_catalogpath;
 extern class QString g_apppath;
