@@ -50,6 +50,7 @@ int g_key=0;
 int g_playmode=0;
 int g_switch = 0;
 long g_nextid=0;
+bool g_debug= false;;
 
 Glcontrol    *g_gl=NULL;
 QString g_prjpath;
@@ -57,6 +58,7 @@ QString g_apppath;
 QString g_editor;
 // Catalog
 QString g_3dcatalogpath;
+int g_3dcatalogkategorie=0;
 QString g_scriptcatalogpath;
 QString g_soundcatalogpath;
 QString g_shadercatalogpath;
