@@ -30,10 +30,6 @@ class CBarrierEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CBarrierEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CBarrierEditDlg();
 
