@@ -30,10 +30,6 @@ class CBodyEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CBodyEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CBodyEditDlg();
 
