@@ -30,10 +30,6 @@ class CCameraEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CCameraEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CCameraEditDlg();
 
