@@ -42,6 +42,7 @@ CCatalogEditDlg::CCatalogEditDlg(QString strTitle, QWidget * parent, QString tmp
    connect(ui.icon, SIGNAL(doubleClicked(QModelIndex)),
              this, SLOT(doubleclick(QModelIndex)));
    fillcombo();
+   ui.comboBox1->setCurrentIndex(g_3dcatalogkategorie);
    fillicon(catfilter);
    ui.catpath->setText( tmppath ) ;
    state=0;
@@ -72,7 +73,8 @@ void CCatalogEditDlg::fillicon(QDir::Filter filters)
 {
     QDir icondir;
     QStringList catlist;
-    icondir.setPath( tmpdir.path() + "/" + ui.comboBox1->currentText());
+       icondir.setPath( tmpdir.path() + "/" + ui.comboBox1->currentText());
+    g_3dcatalogkategorie = ui.comboBox1->currentIndex();
     path =  icondir.path() + "/";
 //     icondir.setFilter(QDir::Dirs);
 //     icondir.setFilter(QDir::Files);
