@@ -31,10 +31,6 @@ class CCatalogEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CCatalogEditDlg(QString, QWidget * parent = 0, QString tmppath = "",QDir::Filter filters=QDir::AllEntries, Qt::WFlags f = 0 );
     ~CCatalogEditDlg();
     QString getfile();
