@@ -30,10 +30,6 @@ class CCursorEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CCursorEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CCursorEditDlg();
 
