@@ -29,10 +29,6 @@ class CDefaultDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CDefaultDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CDefaultDlg();
 
