@@ -30,10 +30,6 @@ class CFireEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CFireEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CFireEditDlg();
 
