@@ -30,10 +30,6 @@ class CFogEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CFogEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CFogEditDlg();
 
