@@ -31,10 +31,6 @@ class CGlobalEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CGlobalEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CGlobalEditDlg();
 
