@@ -30,10 +30,6 @@ class CGUIButtonEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CGUIButtonEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CGUIButtonEditDlg();
 
