@@ -30,10 +30,6 @@ class CGUIInputEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CGUIInputEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CGUIInputEditDlg();
 
