@@ -30,10 +30,6 @@ class CGUIOSButtonEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CGUIOSButtonEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CGUIOSButtonEditDlg();
 
