@@ -30,10 +30,6 @@ class CGUITextEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CGUITextEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CGUITextEditDlg();
 
