@@ -30,10 +30,6 @@ class CLampEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CLampEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CLampEditDlg();
 
