@@ -30,10 +30,6 @@ class CNetworkEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CNetworkEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CNetworkEditDlg();
 
