@@ -30,10 +30,6 @@ class CObjEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CObjEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CObjEditDlg();
 
