@@ -30,10 +30,6 @@ class CPartsysEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CPartsysEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CPartsysEditDlg();
 
