@@ -30,10 +30,6 @@ class CPlayerEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CPlayerEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CPlayerEditDlg();
 
