@@ -31,25 +31,25 @@ class CPrefEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
-    CPrefEditDlg(QString, QWidget * parent = 0, QString tmppath ="", Qt::WFlags f = 0 );
+    CPrefEditDlg(QString, QWidget * parent = 0, QString tmppath ="", int tmpfps=0, int tmpphfps=0,Qt::WFlags f = 0 );
     ~CPrefEditDlg();
     QString geteditpath();
+    int getfps();
+    int getphfps();
 
 public slots:
     virtual void slotGetData();
     virtual void slotEditData();
     void slotGetEditor();
- 
+    void loadFromSettings();
+
 private slots:
  
 protected:
     Ui::PrefEditDlg ui;
     QString editorpath;
-
+    int fps;
+    int phfps;
     
 private:
     QWidget *myParent;
