@@ -30,10 +30,6 @@ class CProjectEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CProjectEditDlg(QWidget * parent = 0);
     QString getfile();
     QString getpath();
