@@ -30,10 +30,6 @@ class CSceneEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CSceneEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CSceneEditDlg();
 
