@@ -30,10 +30,6 @@ class CShaderEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CShaderEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CShaderEditDlg();
 
