@@ -30,10 +30,6 @@ class CSkyEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CSkyEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CSkyEditDlg();
 
