@@ -30,10 +30,6 @@ class CSoundEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CSoundEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CSoundEditDlg();
 
