@@ -30,10 +30,6 @@ class CSplEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CSplEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CSplEditDlg();
 
