@@ -30,10 +30,6 @@ class CWavesysEditDlg: public CQcakeDlg
     Q_OBJECT
       
 public:
-    typedef struct Item{
-        QString strName;
-    };
-
     CWavesysEditDlg(QString, QWidget * parent = 0, Qt::WFlags f = 0 );
     ~CWavesysEditDlg();
 
