@@ -3,7 +3,7 @@
                              -------------------
     begin                : Die Jul 26 2005
     copyright            : (C) 2005 by Krippel Harald
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -15,10 +15,18 @@
  *                                                                         *
  ***************************************************************************/
 
+/**
+ * @class aStar
+ * @brief The aStar class is an implemtation of an pathfinding algorithms
+ */
+
 #include "astar.hpp"
-#include <iostream.h>
-#include <fstream.h>
-#include <stdlib.h>
+
+#include <iostream>                             // Standardstream-Funktionaliät einbinden
+#include <fstream>                              // ofstream und ifstream einbinden
+#include <cstdlib>                              // für abs()
+
+using namespace std;
 
 aStar::aStar(unsigned tmpmapWidth, unsigned tmpmapHeight , unsigned tmptileSize, unsigned tmpnumberPeople){
   int i;
@@ -30,22 +38,22 @@ aStar::aStar(unsigned tmpmapWidth, unsigned tmpmapHeight , unsigned tmptileSize,
   walkable = 0; unwalkable = 1;// walkability array constants
 
   //Create needed arrays
-	walkability = new char*[mapWidth]; //[(const int)mapHeight];
+  walkability = new char*[mapWidth]; //[(const int)mapHeight];
   for (i = 0; i < mapWidth; ++i)
         walkability[i] = new char[mapHeight];
-	map = new char*[mapWidth]; //[(const int)mapHeight];
+        map = new char*[mapWidth]; //[(const int)mapHeight];
   for (i = 0; i < mapWidth; ++i)
         map[i] = new char[mapHeight];
-  
-	openList = new int[mapWidth*mapHeight+2]; //1 dimensional array holding ID# of open list items
+
+  openList = new int[mapWidth*mapHeight+2]; //1 dimensional array holding ID# of open list items
 
   whichList= new int*[mapWidth+1]; //[mapHeight+1];  //2 dimensional array used to record
   for (i = 0; i < mapWidth+1; ++i)
         whichList[i] = new int[mapHeight+1];
 
   // 		whether a cell is on the open list or on the closed list.
-	openX = new int[mapWidth*mapHeight+2]; //1d array stores the x location of an item on the open list
-	openY = new int[mapWidth*mapHeight+2]; //1d array stores the y location of an item on the open list
+  openX = new int[mapWidth*mapHeight+2]; //1d array stores the x location of an item on the open list
+  openY = new int[mapWidth*mapHeight+2]; //1d array stores the y location of an item on the open list
 
   parentX = new int*[mapWidth+1]; //[mapHeight+1]; //2d array to store parent of each cell (x)
   for (i = 0; i < mapWidth+1; ++i)
@@ -62,24 +70,23 @@ aStar::aStar(unsigned tmpmapWidth, unsigned tmpmapHeight , unsigned tmptileSize,
         Gcost[i] = new int[mapHeight+1];
 
   Hcost = new int[mapWidth*mapHeight+2];	//1d array to store H cost of a cell on the open list
-	pathLength = new int[numberPeople+1];     //stores length of the found path for critter
-	pathLocation = new int[numberPeople+1];   //stores current position along the chosen path for critter
-	pathBank = new int*[numberPeople+1];
-	for (i = 0; i < numberPeople+1; i++)
-		pathBank [i] = new int[4];
-  
-	//Path reading variables
-	pathStatus = new int[numberPeople+1];
-	xPath = new int[numberPeople+1];
-	yPath = new int[numberPeople+1];
+  pathLength = new int[numberPeople+1];     //stores length of the found path for critter
+  pathLocation = new int[numberPeople+1];   //stores current position along the chosen path for critter
+  pathBank = new int*[numberPeople+1];
+  for (i = 0; i < numberPeople+1; i++)
+        pathBank [i] = new int[4];
+
+  //Path reading variables
+  pathStatus = new int[numberPeople+1];
+  xPath = new int[numberPeople+1];
+  yPath = new int[numberPeople+1];
 
   for (int x = 0; x < mapWidth; x++){
     for (int y = 0; y < mapHeight; y++){
-	    walkability [x][y] = walkable;
-	    map [x][y] = walkable;
-	  }
+        walkability [x][y] = walkable;
+        map [x][y] = walkable;
+    }
   }
-
 }
 
 //-----------------------------------------------------------------------------
@@ -87,127 +94,113 @@ aStar::aStar(unsigned tmpmapWidth, unsigned tmpmapHeight , unsigned tmptileSize,
 // Desc: Finds a path using A*
 //-----------------------------------------------------------------------------
 int aStar::FindPath (int pathfinderID,int startingX, int startingY,
-			  int targetX, int targetY)
+                     int targetX, int targetY)
 {
   int onOpenList=0, parentXval=0, parentYval=0,
-	a=0, b=0, m=0, u=0, v=0, temp=0, corner=0, numberOfOpenListItems=0,
-	addedGCost=0, tempGcost = 0, path = 0,
-	tempx, pathX, pathY, cellPosition,
-	newOpenListItemID=0;
+  a=0, b=0, m=0, u=0, v=0, temp=0, corner=0, numberOfOpenListItems=0,
+  addedGCost=0, tempGcost = 0, path = 0,
+  tempx, pathX, pathY, cellPosition,
+  newOpenListItemID=0;
 
-//1. Convert location data (in pixels) to coordinates in the walkability array.
-	int startX = startingX/tileSize;
-	int startY = startingY/tileSize;
-	targetX = targetX/tileSize;
-	targetY = targetY/tileSize;
+  //1. Convert location data (in pixels) to coordinates in the walkability array.
+  int startX = startingX/tileSize;
+  int startY = startingY/tileSize;
+  targetX = targetX/tileSize;
+  targetY = targetY/tileSize;
 
-//1.1 Check Values
+  //1.1 Check Values
   if( startX < 0 || startY < 0 || startX >= mapWidth || startY >= mapHeight)
-		return nonexistent;
+      return nonexistent;
   if( targetX < 0 || targetY < 0 || targetX >= mapWidth || targetY >= mapHeight)
-		return nonexistent;
-  
-//2.Quick Path Checks: Under the some circumstances no path needs to
-//	be generated ...
+      return nonexistent;
 
-//	If starting location and target are in the same location...
-	if (startX == targetX && startY == targetY && pathLocation[pathfinderID] > 0)
-		return found;
-	if (startX == targetX && startY == targetY && pathLocation[pathfinderID] == 0)
-		return nonexistent;
+  //2.Quick Path Checks: Under the some circumstances no path needs to
+  //	be generated ...
 
-//	If target square is unwalkable, return that it's a nonexistent path.
-	if (walkability[targetX][targetY] == unwalkable)
-		goto noPath;
+  //	If starting location and target are in the same location...
+  if( startX == targetX && startY == targetY && pathLocation[pathfinderID] > 0)
+      return found;
+  if( startX == targetX && startY == targetY && pathLocation[pathfinderID] == 0)
+      return nonexistent;
+
+  //	If target square is unwalkable, return that it's a nonexistent path.
+  if (walkability[targetX][targetY] == unwalkable)
+      goto noPath;
 
 //3.Reset some variables that need to be cleared
-	if (onClosedList > 1000000) //reset whichList occasionally
-	{
-		for (int x = 0; x < mapWidth;x++) {
-			for (int y = 0; y < mapHeight;y++)
-				whichList [x][y] = 0;
-		}
-		onClosedList = 10;
-	}
-	onClosedList = onClosedList+2; //changing the values of onOpenList and onClosed list is faster than redimming whichList() array
-	onOpenList = onClosedList-1;
-	pathLength [pathfinderID] = notStarted;//i.e, = 0
-	pathLocation [pathfinderID] = notStarted;//i.e, = 0
-	Gcost[startX][startY] = 0; //reset starting square's G value to 0
+  if (onClosedList > 1000000){ //reset whichList occasionally
+      for (int x = 0; x < mapWidth;x++) {
+           for (int y = 0; y < mapHeight;y++)
+                whichList [x][y] = 0;
+      }
+      onClosedList = 10;
+  }
+  onClosedList = onClosedList+2; //changing the values of onOpenList and onClosed list is faster than redimming whichList() array
+  onOpenList = onClosedList-1;
+  pathLength [pathfinderID] = notStarted;//i.e, = 0
+  pathLocation [pathfinderID] = notStarted;//i.e, = 0
+  Gcost[startX][startY] = 0; //reset starting square's G value to 0
 
-//4.Add the starting location to the open list of squares to be checked.
-	numberOfOpenListItems = 1;
-	openList[1] = 1;//assign it as the top (and currently only) item in the open list, which is maintained as a binary heap (explained below)
-	openX[1] = startX ; openY[1] = startY;
+  //4.Add the starting location to the open list of squares to be checked.
+  numberOfOpenListItems = 1;
+  openList[1] = 1;//assign it as the top (and currently only) item in the open list, which is maintained as a binary heap (explained below)
+  openX[1] = startX ; openY[1] = startY;
 
+  //5.Do the following until a path is found or deemed nonexistent.
+  do{
+  //6.If the open list is not empty, take the first cell off of the list.
+  //	This is the lowest F cost cell on the open list.
+      if (numberOfOpenListItems != 0){
+        //7. Pop the first item off the open list.
+        parentXval = openX[openList[1]];
+        parentYval = openY[openList[1]]; //record cell coordinates of the item
+        whichList[parentXval][parentYval] = onClosedList;//add the item to the closed list
 
-//5.Do the following until a path is found or deemed nonexistent.
-	do
-	{
+        //	Open List = Binary Heap: Delete this item from the open list, which
+        //  is maintained as a binary heap. For more information on binary heaps, see:
+        //	http://www.policyalmanac.org/games/binaryHeaps.htm
+        numberOfOpenListItems = numberOfOpenListItems - 1;//reduce number of open list items by 1
 
-//6.If the open list is not empty, take the first cell off of the list.
-//	This is the lowest F cost cell on the open list.
-	if (numberOfOpenListItems != 0)
-	{
+        //	Delete the top item in binary heap and reorder the heap, with the lowest F cost item rising to the top.
+        openList[1] = openList[numberOfOpenListItems+1];//move the last item in the heap up to slot #1
+        v = 1;
 
-//7. Pop the first item off the open list.
-	parentXval = openX[openList[1]];
-	parentYval = openY[openList[1]]; //record cell coordinates of the item
-	whichList[parentXval][parentYval] = onClosedList;//add the item to the closed list
+        //	Repeat the following until the new item in slot #1 sinks to its proper spot in the heap.
+        do{
+          u = v;
+          if (2*u+1 <= numberOfOpenListItems){ //if both children exist
+              //Check if the F cost of the parent is greater than each child.
+              //Select the lowest of the two children.
+              if (Fcost[openList[u]] >= Fcost[openList[2*u]])
+                 v = 2*u;
+              if (Fcost[openList[v]] >= Fcost[openList[2*u+1]])
+                 v = 2*u+1;
+          }else{
+              if (2*u <= numberOfOpenListItems){ //if only child #1 exists
+                 //Check if the F cost of the parent is greater than child #1
+                 if (Fcost[openList[u]] >= Fcost[openList[2*u]])
+                     v = 2*u;
+              }
+          }
 
-//	Open List = Binary Heap: Delete this item from the open list, which
-//  is maintained as a binary heap. For more information on binary heaps, see:
-//	http://www.policyalmanac.org/games/binaryHeaps.htm
-	numberOfOpenListItems = numberOfOpenListItems - 1;//reduce number of open list items by 1
+          if (u != v){ //if parent's F is > one of its children, swap them
+             temp = openList[u];
+             openList[u] = openList[v];
+             openList[v] = temp;
+          }else
+             break; //otherwise, exit loop
+        }
+        while (1);//reorder the binary heap
 
-//	Delete the top item in binary heap and reorder the heap, with the lowest F cost item rising to the top.
-	openList[1] = openList[numberOfOpenListItems+1];//move the last item in the heap up to slot #1
-	v = 1;
-
-//	Repeat the following until the new item in slot #1 sinks to its proper spot in the heap.
-	do
-	{
-	u = v;
-	if (2*u+1 <= numberOfOpenListItems) //if both children exist
-	{
-	 	//Check if the F cost of the parent is greater than each child.
-		//Select the lowest of the two children.
-		if (Fcost[openList[u]] >= Fcost[openList[2*u]])
-			v = 2*u;
-		if (Fcost[openList[v]] >= Fcost[openList[2*u+1]])
-			v = 2*u+1;
-	}
-	else
-	{
-		if (2*u <= numberOfOpenListItems) //if only child #1 exists
-		{
-	 	//Check if the F cost of the parent is greater than child #1
-			if (Fcost[openList[u]] >= Fcost[openList[2*u]])
-				v = 2*u;
-		}
-	}
-
-	if (u != v) //if parent's F is > one of its children, swap them
-	{
-		temp = openList[u];
-		openList[u] = openList[v];
-		openList[v] = temp;
-	}
-	else
-		break; //otherwise, exit loop
-
-	}
-	while (1);//reorder the binary heap
-
-//7.Check the adjacent squares. (Its "children" -- these path children
-//	are similar, conceptually, to the binary heap children mentioned
-//	above, but don't confuse them. They are different. Path children
-//	are portrayed in Demo 1 with grey pointers pointing toward
-//	their parents.) Add these adjacent child squares to the open list
-//	for later consideration if appropriate (see various if statements
-//	below).
-	for (b = parentYval-1; b <= parentYval+1; b++){
-	for (a = parentXval-1; a <= parentXval+1; a++){
+        //7.Check the adjacent squares. (Its "children" -- these path children
+        //	are similar, conceptually, to the binary heap children mentioned
+        //	above, but don't confuse them. They are different. Path children
+        //	are portrayed in Demo 1 with grey pointers pointing toward
+        //	their parents.) Add these adjacent child squares to the open list
+        //	for later consideration if appropriate (see various if statements
+        //	below).
+        for (b = parentYval-1; b <= parentYval+1; b++){
+        for (a = parentXval-1; a <= parentXval+1; a++){
 
 //	If not off the map (do this first to avoid array out-of-bounds errors)
 	if (a != -1 && b != -1 && a != mapWidth && b != mapHeight){
@@ -462,109 +455,97 @@ void aStar::ReadPath(int pathfinderID,int currentX,int currentY, int pixelsPerFr
 ;	to being a problem.
 */
 
-	int ID = pathfinderID; //redundant, but makes the following easier to read
+    int ID = pathfinderID; //redundant, but makes the following easier to read
 
-	//If a path has been found for the pathfinder	...
-	if (pathStatus[ID] == found)
-	{
+    //If a path has been found for the pathfinder	...
+    if (pathStatus[ID] == found){
 
-		//If path finder is just starting a new path or has reached the
-		//center of the current path square (and the end of the path
-		//hasn't been reached), look up the next path square.
-		if (pathLocation[ID] < pathLength[ID])
-		{
-			//if just starting or if close enough to center of square
-			if (pathLocation[ID] == 0 ||
-				(abs(currentX - xPath[ID]) < pixelsPerFrame && abs(currentY - yPath[ID]) < pixelsPerFrame))
-					pathLocation[ID] = pathLocation[ID] + 1;
-		}
+        //If path finder is just starting a new path or has reached the
+        //center of the current path square (and the end of the path
+        //hasn't been reached), look up the next path square.
+        if (pathLocation[ID] < pathLength[ID]){
+            //if just starting or if close enough to center of square
+            if (pathLocation[ID] == 0 || (abs(currentX - xPath[ID]) < pixelsPerFrame && abs(currentY - yPath[ID]) < pixelsPerFrame))
+                pathLocation[ID] = pathLocation[ID] + 1;
+        }
 
-		//Read the path data.
-		xPath[ID] = ReadPathX(ID,pathLocation[ID]);
-		yPath[ID] = ReadPathY(ID,pathLocation[ID]);
+        //Read the path data.
+        xPath[ID] = (int) ReadPathX(ID,pathLocation[ID]);
+        yPath[ID] = (int) ReadPathY(ID,pathLocation[ID]);
 
-		//If the center of the last path square on the path has been
-		//reached then reset.
-		if (pathLocation[ID] == pathLength[ID])
-		{
-			if (abs(currentX - xPath[ID]) < pixelsPerFrame
-				&& abs(currentY - yPath[ID]) < pixelsPerFrame) //if close enough to center of square
-					pathStatus[ID] = notStarted;
-		}
-	}
-
-	//If there is no path for this pathfinder, simply stay in the current
- 	//location.
-	else
-	{
-		xPath[ID] = currentX;
-		yPath[ID] = currentY;
-	}
+        //If the center of the last path square on the path has been
+        //reached then reset.
+        if (pathLocation[ID] == pathLength[ID]){
+            if (abs(currentX - xPath[ID]) < pixelsPerFrame
+                && abs(currentY - yPath[ID]) < pixelsPerFrame) //if close enough to center of square
+                pathStatus[ID] = notStarted;
+        }
+    }else{
+    //If there is no path for this pathfinder, simply stay in the current
+    //location.
+    xPath[ID] = currentX;
+    yPath[ID] = currentY;
+    }
 }
 
 double aStar::ReadPathX(int pathfinderID,int pathLocation)
 {
-	double x=-1;
-	if (pathLocation <= pathLength[pathfinderID])
-	{
+    double x=-1;
+    if (pathLocation <= pathLength[pathfinderID]){
 
-	//Read coordinate from bank
-	x = pathBank[pathfinderID] [pathLocation*2-2];
+        //Read coordinate from bank
+        x = pathBank[pathfinderID] [pathLocation*2-2];
 
-	//Adjust the coordinates so they align with the center
-	//of the path square (optional). This assumes that you are using
-	//sprites that are centered -- i.e., with the midHandle command.
-	//Otherwise you will want to adjust this.
-	x = tileSize*x + .5*tileSize;
-
-	}
-	return x;
+        //Adjust the coordinates so they align with the center
+        //of the path square (optional). This assumes that you are using
+        //sprites that are centered -- i.e., with the midHandle command.
+        //Otherwise you will want to adjust this.
+        x = tileSize*x + .5*tileSize;
+    }
+    return x;
 }
 
 double aStar::ReadPathY(int pathfinderID,int pathLocation)
 {
-	double y=-1;
-	if (pathLocation <= pathLength[pathfinderID])
-	{
+    double y=-1;
+    if (pathLocation <= pathLength[pathfinderID]){
 
-	//Read coordinate from bank
-	y = pathBank[pathfinderID] [pathLocation*2-1];
+        //Read coordinate from bank
+        y = pathBank[pathfinderID] [pathLocation*2-1];
 
-	//Adjust the coordinates so they align with the center
-	//of the path square (optional). This assumes that you are using
-	//sprites that are centered -- i.e., with the midHandle command.
-	//Otherwise you will want to adjust this.
-	y = tileSize*y + .5*tileSize;
+        //Adjust the coordinates so they align with the center
+        //of the path square (optional). This assumes that you are using
+        //sprites that are centered -- i.e., with the midHandle command.
+        //Otherwise you will want to adjust this.
+        y = tileSize*y + .5*tileSize;
 
-	}
-	return y;
+    }
+    return y;
 }
 
 int aStar::ReadMap(const char *filename)
 {
       ifstream filein;
       filein.open(filename,ios::in);
-      if (filein)
-      {
+      if (filein){
         for (int y = 0; y < mapHeight; y++){
           for (int x = 0; x < mapWidth; x++){
               filein >> walkability [x][y];//or filein.read(buffer,length)
               map[x][y]= walkability [x][y];
               if (walkability [x][y] == '.') walkability [x][y] = walkable;
               else  walkability [x][y] = unwalkable;	
-           }
-         }
-         filein.close();
-         return 0;
-       }else{
+          }
+        }
+        filein.close();
+        return 0;
+      }else{
          return 1;
-       }
+      }
 }
 
 int aStar::ReadMapValue(int x ,int y)
 {
-  if(x >= 0 && x < mapWidth && y >= 0 && y < mapHeight )
-  {
+  if(x >= 0 && x < mapWidth && y >= 0 && y < mapHeight ){
      return(map[x][y]);
   }
   return(0);
@@ -598,8 +579,8 @@ aStar::~aStar(){
   delete[] Hcost;
   delete[] pathLength;
   delete[] pathLocation;
-	for (i = 0; i < numberPeople+1; i++)
-		  delete[] pathBank [i];
+  for (i = 0; i < numberPeople+1; i++)
+       delete[] pathBank [i];
   delete[] pathBank;
   delete[] pathStatus;
   delete[] xPath;
