@@ -266,7 +266,8 @@ int AudioEnv::LoadFile (const char *filename, bool loop)
 #endif
 
 #ifdef MACOS
-        alutLoadVorbisp = (vorbisLoader *) alGetProcAddress((ALubyte *) VORBIS_FUNC);
+    //    alutLoadVorbisp = (vorbisLoader *) alGetProcAddress((ALubyte *) VORBIS_FUNC);
+		alutLoadVorbisp = (vorbisLoader *) alGetProcAddress((ALchar *) VORBIS_FUNC);
 #endif
 
 #ifdef WINDOWS
