@@ -16,19 +16,26 @@
 #include <qglobal.h>
 #include <QObject>
 
-#include <AL/al.h>
-#include <AL/alut.h>
 
 #ifdef    Q_OS_LINUX
   #define LINUX
+  #include <AL/al.h>
+  #include <AL/alut.h>
 #endif
 
 #ifdef    Q_OS_MACX
   #define MACOS
+#import <OpenAL/al.h>
+#import <OpenAL/alc.h>
+#include <AL/alut.h>
+//#include <OpenAL/alut.h>
+//  #include <OpenAL/alut.h>
 #endif
 
 #ifdef    Q_OS_WIN32
   #define WINDOWS
+  #include <AL/al.h>
+  #include <AL/alut.h>
 #endif
 
 #define ALBUFFERSIZE 1024*16
