@@ -20,6 +20,7 @@
  * @brief Camera manipulator class for use with plib
  */
 
+#include "globdefines.h"
 #include "camera.hpp"
 
 const sgVec3 Camera::Xaxis = {1.0,0.0,0.0};
@@ -28,7 +29,7 @@ const sgVec3 Camera::Zaxis = {0.0,0.0,1.0};
 
 Camera::Camera(){
   ssgSetFOV     ( 60.0f, 0.0f ) ;
-  ssgSetNearFar ( 0.01f, 100000.0f ) ; /* nb. skydome is scalable ... so far can be reduced */
+  ssgSetNearFar ( 0.01f, MAX_FAR ) ; /* nb. skydome is scalable ... so far can be reduced */
   sgCoord campos ;
   sgSetCoord ( & campos, 0.0f, -50.0, 0.0f, 0.0f, 0.0f, 0.0f ) ;
   ssgSetCamera ( & campos ) ;
@@ -122,13 +123,10 @@ void Camera::getEyePoint(sgVec3* eye){
     - cameraMatrix[2][1]*cameraMatrix[3][1] - cameraMatrix[2][2]*cameraMatrix[3][2];
 }
             
-void Camera::tilt(const SGfloat a, const sgVec3 axis){
+void Camera::tiltglobal(const SGfloat a, const sgVec3 axis){
   sgVec4 v;
-  sgMat4 M;
   
   v[0] = axis[0]; v[1] = axis[1]; v[2] = axis[2]; v[3]=0.0f;
-  sgInvertMat4(M, cameraMatrix);
-  sgXformPnt4(v, M);
   
   translate(POI);
   rotate(a, v);
@@ -136,6 +134,20 @@ void Camera::tilt(const SGfloat a, const sgVec3 axis){
   sgNegateVec3(v);
   translate(v);    
 }
+void Camera::tilt(const SGfloat a, const sgVec3 axis){
+  sgVec4 v;
+  sgMat4 M;
+
+  v[0] = axis[0]; v[1] = axis[1]; v[2] = axis[2]; v[3]=0.0f;
+  sgInvertMat4(M, cameraMatrix);
+  sgXformPnt4(v, M);
+
+  translate(POI);
+  rotate(a, v);
+  sgCopyVec3(v, POI);
+  sgNegateVec3(v);
+  translate(v);
+}
 
 void Camera::pan(const int x, const int y){
   // move camera parallel to viewplane, so that POI appears at x,y. 
