@@ -259,11 +259,10 @@ void    Glcontrol::gtimerDone()
     updateGL();
 
     if(g_playmode){
-      my_context->makeCurrent();
       // get3DMouse Update
       QPoint mpoint = mapFromGlobal(QCursor::pos());
 // Debian etch problem with Intel Graphics driver!!!!!!
-//      my_context->setPOI(mpoint.x(), mpoint.y());
+      my_context->setPOI(mpoint.x(), mpoint.y());
       my_context->getPOI(&g_poi);
       g_mouse_x = mpoint.x();
       g_mouse_y = mpoint.y();
@@ -332,7 +331,6 @@ void Glcontrol::puRedraw()
 
 Glcontrol::~Glcontrol()
 {
-    makeCurrent();
     if(phthread){
       phthread->go = 0;
       phthread->wait();
@@ -369,9 +367,7 @@ void Glcontrol::load_database ()
   ssgTexturePath ( "data" ) ;
 
   /*
-    Create a root node - and a transform to position
-    the pedestal - and another to position the penguin
-    beneath that (in the tree that is).
+    Create a root node
   */
 
   scene = new ssgRoot();
@@ -388,58 +384,24 @@ void Glcontrol::load_database ()
 
 void Glcontrol::init_gui ()
 {
-
-/*    
-  static puFont     *sorority ;
-  static fntTexFont *fnt      ;
-
-  fnt      = new fntTexFont () ;
-//  fnt     -> load ( "Courier.txf" ) ;
-  fnt     -> load ( "Times-Roman.txf" ) ;
-//  fnt     -> load ( "Helvetica.txf" ) ;
-  sorority = new puFont ( fnt, 14 ) ;
-
-  puSetDefaultFonts        ( *sorority, *sorority ) ;
-  puSetDefaultStyle        ( PUSTYLE_SHADED ) ;
-  puSetDefaultColourScheme ( 0.2f, 0.5f, 0.2f, 0.5f ) ;
-
-*/
   timeText = new puText ( 40, 40 ) ;
   timeText->setColour( PUCOL_LABEL, FONT_COLOUR ) ;
   phText = new puText ( 40, 20 ) ;
   phText->setColour( PUCOL_LABEL, FONT_COLOUR ) ;
-
 }
 
 void Glcontrol::init_graphics ()
 {
-  /*
-    Initialise SSG
-  */
   puInitQT ();
   ssgInit () ;
   jsInit () ;
-  /*
-    Some basic OpenGL setup
-  */
-  glClearColor ( 0.2f, 0.7f, 1.0f, 1.0f ) ;
-  glColor4f(1.0f,1.0f,1.0f,0.5f);
-  glEnable ( GL_DEPTH_TEST ) ;
-//  glEnable(GL_TEXTURE_2D);
-//  glEnable(GL_BLEND);
-//  glEnable(GL_ALPHA_TEST);
-//  glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);
-//  glDisable(GL_DEPTH_TEST);        // Turn Depth Testing Off
-
   my_context = new Camera; 
-  my_context->makeCurrent();
 }
 
 void Glcontrol::updatePH ()
 {
   static ulClock ck ;
   static float waitoffs = 20;
-//  int a;
   float wait;
   static int state=0;
 
@@ -585,13 +547,17 @@ void Glcontrol::update_motion ()
 
 void Glcontrol::paintGL()
 {
-  my_context->makeCurrent();
-
+  glClearColor ( 0.2f, 0.7f, 1.0f, 1.0f ) ;
+  glColor4f(1.0f,1.0f,1.0f,0.5f);
+  glEnable ( GL_DEPTH_TEST ) ;
   glClear  ( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT ) ;
   glDisable ( GL_FOG ) ;
   glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   glEnable ( GL_BLEND ) ;
 
+  glMatrixMode(GL_PROJECTION);
+  glPushMatrix();
+
   update_motion () ;
 
   emit msg_predraw();
@@ -599,15 +565,17 @@ void Glcontrol::paintGL()
   emit msg_postdraw();
 
   puDisplay () ;
+
+  glMatrixMode(GL_PROJECTION);
+  glPopMatrix();
 }
 
 /*!
-  Set up the OpenGL rendering state, and define display list
+  Set up the OpenGL rendering state
 */
 
 void Glcontrol::initializeGL()
 {
-  makeCurrent();   // test
   init_graphics () ;
   load_database () ;
   init_gui();
@@ -715,9 +683,9 @@ void Glcontrol::setScaleImpulse( double x, double y, double z )
 void Glcontrol::mousePressEvent( QMouseEvent *e )
 {
     setFocus ();
+  //  qDebug() << "Press Event " <<  e->pos().x() << "  " << e->pos().y();
     e->accept();
     oldPos = e->pos();
-    makeCurrent();
     my_context->setPOI(e->pos().x(), e->pos().y());
     if(g_playmode){
       /* PUI */
@@ -799,11 +767,12 @@ void Glcontrol::mouseMoveEvent( QMouseEvent *e )
       if (e->buttons() & Qt::LeftButton){
         QPoint point = e->pos()-oldPos;
         if (point != QPoint(0,0)) {
-//        my_context->tilt((point.x()>0)?1.0:-1.0,Camera::Yaxis);
-//        my_context->tilt((point.y()>0)?1.0:-1.0,Camera::Xaxis);
-//        my_context->tilt(point.y(),Camera::Xaxis);
-          my_context->tilt(point.x(),Camera::Yaxis);
-          my_context->tilt(point.y(),Camera::Xaxis);
+          if(g_keyset.contains( Qt::Key_Shift)){
+            my_context->tilt(point.y(),Camera::Xaxis);
+          }
+ //         else{
+            my_context->tiltglobal(point.x(),Camera::Zaxis);
+ //         }
           updateGL();
 #ifndef    Q_OS_MACX
           QCursor::setPos(mapToGlobal(oldPos));	// dont work correct under QT OSX 10.3.6
@@ -811,13 +780,13 @@ void Glcontrol::mouseMoveEvent( QMouseEvent *e )
         }
       }
       else if (e->buttons() & Qt::RightButton){
+//        qDebug() << "Move Event " <<  e->pos().x() << "  " << e->pos().y();
         my_context->pan(e->pos().x(), e->pos().y());
         updateGL();
       }
       else if (e->buttons() & Qt::MidButton){
         QPoint point = e->pos()-oldPos;
         if (point != QPoint(0,0)) {
-//        my_context->walk((point.y()>0)?1.0:-1.0);
           my_context->walk(point.y());
           updateGL();
 #ifndef    Q_OS_MACX
@@ -972,15 +941,14 @@ void Glcontrol::keyPressEvent(QKeyEvent *e)
        if(usercam != NULL){
              usercam -> kbd (e->key()) ;
        }
-       // keyset
-       if (!e->isAutoRepeat()) {
-          if(g_playmode){
-//            QString s = QString("Pressed: %1 %2").arg(e->key());
-//            qDebug() << s;
-            g_keyset.insert(e->key());
-        }
     }
+    // keyset
+    if (!e->isAutoRepeat()) {
+//          QString s = QString("Pressed: %1 %2").arg(e->key());
+//          qDebug() << s;
+          g_keyset.insert(e->key());
     }
+
     e->ignore();
 }
 
@@ -1751,7 +1719,7 @@ void Glcontrol::addSPLFile(FolderListItem * i, QString path , QString file, ssgT
 
       i->gl=this;
       tmpfile = path + "/" + file;
-      i->scriptprog = new splPrg(tmpfile.toAscii().constData());
+      i->scriptprog = new splPrg(tmpfile.toAscii().constData(), i->GetValue("tmpid").toInt());
       connect(this, SIGNAL(msg_ph_update (const QString &)),i->scriptprog , SLOT(slot_update(const QString &)));
       connect(this, SIGNAL(msg_compile()),i->scriptprog , SLOT(slot_compile()));
       setFocusScriptprg(i);
@@ -1764,7 +1732,7 @@ void Glcontrol::addQTSFile(FolderListItem * i, QString path , QString file, ssgT
 
       i->gl=this;
       tmpfile = path + "/" + file;
-      i->scriptprog = new qtscriptPrg(tmpfile.toAscii().constData());
+      i->scriptprog = new qtscriptPrg(tmpfile.toAscii().constData(), i->GetValue("tmpid").toInt());
       connect(this, SIGNAL(msg_ph_update (const QString &)),i->scriptprog , SLOT(slot_update(const QString &)));
       connect(this, SIGNAL(msg_compile()),i->scriptprog , SLOT(slot_compile()));
       setFocusScriptprg(i);
@@ -1777,7 +1745,7 @@ void Glcontrol::addPythonFile(FolderListItem * i, QString path , QString file, s
 
       i->gl=this;
       tmpfile = path + "/" + file;
-      i->scriptprog = new python_prg(tmpfile.toAscii().constData());
+      i->scriptprog = new python_prg(tmpfile.toAscii().constData(), i->GetValue("tmpid").toInt());
       connect(this, SIGNAL(msg_ph_update (const QString &)),i->scriptprog , SLOT(slot_update(const QString &)));
       connect(this, SIGNAL(msg_compile()),i->scriptprog , SLOT(slot_compile()));
       setFocusScriptprg(i);
@@ -1847,9 +1815,14 @@ int Glcontrol::addShader(FolderListItem * i, ssgTransform *obj)
 
          // load the vertex and pixel-schader file from the project folder
          if ((! tmpvfile.isEmpty()) && (! tmpffile.isEmpty())){
+            i->setText( 0, result);
+            i->SetValue("path","data/" + result);
             QFileInfo f(tmpffile);
-            QString sname = f.fileName();
-            i->SetValue("ffile",sname);
+            QString fname = f.fileName();
+            i->SetValue("ffile",fname);
+            QFileInfo v(tmpvfile);
+            QString vname = v.fileName();
+            i->SetValue("vfile",vname);
             tmpvfile = tmpdirv.path() + "/" + tmpvfile;
             tmpffile = tmpdirf.path() + "/" + tmpffile;
             qWarning( tmpvfile.toAscii() );
@@ -2165,6 +2138,7 @@ void Glcontrol::setFocusObject(FolderListItem * i)
 {
   sgCoord       pos ;
 
+
     if(i->objtrans != NULL){
       // x,y,z,h,p,r
       sgSetCoord ( &pos,
@@ -2192,7 +2166,7 @@ void Glcontrol::setFocusObject(FolderListItem * i)
                                       i->GetValue("scax").toFloat(),
                                       i->GetValue("scay").toFloat(),
                                       i->GetValue("scaz").toFloat()) ;
-          i->objtrans->recalcBSphere();
+
           if(i->tribarrier != NULL){
              i->tribarrier->pos.xyz[0] = i->GetValue("x").toFloat();
              i->tribarrier->pos.xyz[1] = i->GetValue("y").toFloat();
@@ -2202,6 +2176,9 @@ void Glcontrol::setFocusObject(FolderListItem * i)
              i->tribarrier->pos.hpr[1] = i->GetValue("roty").toFloat();
              i->tribarrier->pos.hpr[2] = i->GetValue("rotz").toFloat();
              i->tribarrier->SetPosition ();
+             i->tribarrier->setScale(i->GetValue("scax").toFloat(),
+                                      i->GetValue("scay").toFloat(),
+                                      i->GetValue("scaz").toFloat());
           }
       }
    }
@@ -2649,6 +2626,13 @@ void Glcontrol::setFocusMedia(FolderListItem * i)
        i->media->Loop(0);
      }
 
+     if(i->GetValue("fullscreen").toInt() == 1){
+       i->media->setFullScreen(true);
+     } else {
+       i->media->setFullScreen(false);
+     }
+
+
      if(i->GetValue("play").toInt() == 1){
        i->media->slot_play();
      }
@@ -2673,20 +2657,7 @@ void  Glcontrol::setFocusScriptprg(FolderListItem * i)
           qWarning(  "setFocusScriptprg No Scripting Object " );
   }
 }
-/*
-void  Glcontrol::setFocusShader(FolderListItem * i)
-{
-  if(i->gshader != NULL){
-    if(i->GetValue("on").toInt() == 1){
-        i->gshader->TurnOn();
-    } else {
-        i->gshader->TurnOff();
-    }
-  } else {
-          qWarning(  "setFocusShader No Shader Object " );
-  }
-}
-*/
+
 void Glcontrol::setFocusPartSys(FolderListItem * i)
 {
     if(i->partsys != NULL){
@@ -2984,31 +2955,30 @@ void Glcontrol::setFocusWaveSys(FolderListItem * i)
   }
 }
 
-void  Glcontrol::viewCamera(FolderListItem * i)
+void  Glcontrol::viewCamera(usercamera * usercam)
 {
   sgCoord campos ;
 
-  if(i != NULL && i->usercam != NULL){
-      i->usercam->view();
+  if(usercam != NULL){
+      usercam->view();
   } else {
       qWarning(  "viewCamera No usercamera Object " );
       ssgSetFOV     ( 60.0f, 0.0f ) ;
-      ssgSetNearFar ( 0.01f, 100000.0f ) ;
+      ssgSetNearFar ( 0.01f, MAX_FAR ) ;
       sgSetCoord ( & campos, 0.0f, -5.0f*scale, 3.0f, 0.0f, 0.0f, 0.0f ) ;
       my_context -> setCamera ( & campos );
-      resizeGL( g_window_w, g_window_h );
+      resizeGL( width(), height() );
+//      resizeGL( g_window_w, g_window_h );
   }
 }
 
 void  Glcontrol::switchCamera(FolderListItem * i)
 {
+    usercam = NULL;
+    if(i != NULL){
     usercam = i->usercam;
-    viewCamera(i);
 }
-
-void  Glcontrol::makemyCurrent()
-{
-    my_context->makeCurrent();
+    viewCamera(usercam);
 }
 
 void Glcontrol::changeAttribute (FolderListItem * i, char *attr, char *value)
@@ -3053,6 +3023,9 @@ void Glcontrol::changeAttribute (FolderListItem * i, char *attr, char *value)
     if(i->text(1) == "SOUND"){
        setFocusSound(i);
     }
+    if(i->text(1) == "MEDIA"){
+       setFocusMedia(i);
+    }
     if(i->text(1) == "WAVESYS"){
        setFocusWaveSys(i);
     }
@@ -3135,10 +3108,8 @@ int  Glcontrol::compile()
 void Glcontrol::keyReleaseEvent ( QKeyEvent * e )
 {
     if (!e->isAutoRepeat()) {
-        if(g_playmode){
 //          QString s = QString("Released: %1 %2").arg(e->key());
 //          qDebug() << s;
           g_keyset.remove(e->key());
-        }
     }
 }
