@@ -121,7 +121,6 @@ public slots:
     void    setFocusPartSys(FolderListItem * i);
 
     void    StopSound();
-    void    viewCamera(FolderListItem * i);
     void    switchCamera(FolderListItem * i);
     int     loadObject(FolderListItem * i, ssgTransform *obj);
     void    addFire(FolderListItem * i, ssgTransform *obj);
@@ -163,7 +162,7 @@ public slots:
     int     addTmpObject(FolderListItem * i, FolderListItem * imodel, ssgTransform *obj, sgCoord pos, int id);
 
     ssgTransform*    loadObjectFile(QString path , QString file, ssgTransform *obj);
-    void    makemyCurrent();
+
     void    DeleteScene();
     void    redrawScene();
     void    gtimerDone();
@@ -215,6 +214,7 @@ protected:
 
 
 protected slots:
+    void    viewCamera(usercamera * usercam);
 
 private:
     FolderListItem *focusitem;
