@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Jun 15 2004
     copyright            : (C) 2004 by Harald Krippel
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,6 +24,11 @@
 
 #include <plib/pu.h>
 
+/*!
+
+ This Class is the glue between PLIB puButton and QCake.
+
+*/
 class GUIButton : public puButton  {
 public: 
 	GUIButton(int minx, int miny, const char *l);
