@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Jun 15 2004
     copyright            : (C) 2004 by Harald Krippel
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
@@ -24,7 +24,11 @@
 
 #include <plib/pu.h>
 
+/*!
 
+ This Class is the glue between PLIB puInput and QCake.
+
+*/
 class GUIInput : public puInput  {
 public: 
 	GUIInput(int minx, int miny, int maxx, int maxy);
