@@ -3,7 +3,7 @@
                              -------------------
     begin                : Tue Jun 15 2004
     copyright            : (C) 2004 by Harald Krippel
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
