@@ -3,7 +3,7 @@
                              -------------------
     begin                : Die Jul 5 2005
     copyright            : (C) 2005 by Krippel Harald
-    email                : neuro.harald@surfeu.at
+    email                : harald@hte-develop.net
  ***************************************************************************/
 
 /***************************************************************************
