@@ -39,6 +39,8 @@ extern int g_key;
 extern int g_playmode;
 extern int g_switch;
 extern long g_nextid;
+extern bool g_debug;
+
 // Display
 extern int g_displayfps;
 extern int g_displayphfps;
@@ -51,6 +53,7 @@ extern class FolderListItem * g_switchScene;
 extern class QString g_prjpath;
 extern class QString g_editor;
 extern class QString g_3dcatalogpath;
+extern  int g_3dcatalogkategorie;
 extern class QString g_scriptcatalogpath;
 extern class QString g_soundcatalogpath;
 extern class QString g_shadercatalogpath;
