@@ -402,110 +402,99 @@ void MainWindow::aboutPlugins()
 void MainWindow::createActions()
 {
     fileNewAct = new QAction(QIcon(":/images/filenew.png"), tr("&New"), this);
-//    fileNewAct->setShortcut((tr("Ctrl+N"))); // did not work at the moment with QT4.3.4 
     fileNewAct->setShortcut(QKeySequence("Ctrl+N"));
     fileNewAct->setStatusTip(tr("Create a new project"));
     connect(fileNewAct, SIGNAL(triggered()), this, SLOT(newProject()));
 
     fileOpenAct = new QAction(QIcon(":/images/fileopen.png"), tr("&Open ..."), this);
-//    fileOpenAct->setShortcut(tr("Ctrl+O"));
     fileOpenAct->setShortcut(QKeySequence("Ctrl+O"));
     fileOpenAct->setStatusTip(tr("Open a project"));
     connect(fileOpenAct, SIGNAL(triggered()), this, SLOT(open()));
 
     fileSaveAct = new QAction(QIcon(":/images/filesave.png"), tr("&Save"), this);
-//    fileSaveAct->setShortcut(tr("Ctrl+S"));
     fileSaveAct->setShortcut(QKeySequence("Ctrl+S"));
     fileSaveAct->setStatusTip(tr("Save the current project"));
     connect(fileSaveAct, SIGNAL(triggered()), this, SLOT(save()));
 
     filePrintAct = new QAction(QIcon(":/images/print.png"), tr("&Print ..."), this);
-//    filePrintAct->setShortcut(tr("Ctrl+P"));
     filePrintAct->setShortcut(QKeySequence("Ctrl+P"));
     filePrintAct->setStatusTip(tr("Print the current ??"));
     connect(filePrintAct, SIGNAL(triggered()), this, SLOT(print()));
 
 //    filePrefAct = new QAction(QIcon(":/images/print.png"), tr("&Preferences ..."), this);
     filePrefAct = new QAction(tr("&Preferences ..."), this);
-//    filePrefAct->setShortcut(tr("Ctrl+F"));
     filePrefAct->setShortcut(QKeySequence("Ctrl+F"));
     filePrefAct->setStatusTip(tr("Preferences"));
     connect(filePrefAct, SIGNAL(triggered()), this, SLOT(preferences()));
 
     editUndoAct = new QAction(QIcon(":/images/undo.png"), tr("&Undo"), this);
-//    editUndoAct->setShortcut(tr("Ctrl+Z"));
     editUndoAct->setShortcut(QKeySequence("Ctrl+Z"));
     editUndoAct->setStatusTip(tr("Undo the last editing action"));
     connect(editUndoAct, SIGNAL(triggered()), this, SLOT(undo()));
 
     editCutAct = new QAction(tr("&Cut"), this);
-//    editCutAct->setShortcut(tr("Ctrl+C"));
     editCutAct->setShortcut(QKeySequence("Ctrl+C"));
     editCutAct->setStatusTip(tr("Cut the selected item"));
     connect(editCutAct, SIGNAL(triggered()), this, SLOT(cut()));
 
     fileQuitAct = new QAction(tr("&Quit"), this);
-//    fileQuitAct->setShortcut(QKeySequence(tr("Ctrl+Q")));
-//    fileQuitAct->setShortcut(tr("Ctrl+Q", "Quit"));
     fileQuitAct->setShortcut(QKeySequence("Ctrl+Q"));
     fileQuitAct->setStatusTip(tr("Quit the application"));
     connect(fileQuitAct, SIGNAL(triggered()), this, SLOT(close()));
 
     viewFullScreenAct = new QAction(tr("&FullScreen"), this);
-//    viewFullScreenAct->setShortcut(tr("Ctrl+F"));
     viewFullScreenAct->setStatusTip(tr("full screen view"));
     connect(viewFullScreenAct, SIGNAL(triggered()), this, SLOT(slotFullScreen()));
 
     viewFrontScreenAct = new QAction(tr("&FrontView"), this);
-//    viewFrontScreenAct->setShortcut(tr("Ctrl+2"));
     viewFrontScreenAct->setShortcut(QKeySequence("Ctrl+2"));
     viewFrontScreenAct->setStatusTip(tr("fornt view"));
     connect(viewFrontScreenAct, SIGNAL(triggered()), this, SLOT(slotFrontView()));
 
+    viewDebugAct = new QAction(tr("&Debug"), this);
+    viewDebugAct->setShortcut(QKeySequence("Ctrl+D"));
+    viewDebugAct->setStatusTip(tr("Debug Mode"));
+    viewDebugAct->setCheckable(true);
+    connect(viewDebugAct, SIGNAL(triggered()), this, SLOT(slotDebugMode()));
+
+
     toolsEditCamAct = new QAction(QIcon(":/images/wizard.png"),tr("&EditCam"), this);
-//    toolsEditCamAct->setShortcut(tr("Ctrl+K"));
     toolsEditCamAct->setShortcut(QKeySequence("Ctrl+K"));
     toolsEditCamAct->setStatusTip(tr("EditorCamera"));
     toolsEditCamAct->setWhatsThis(tr("Editor Camera\n\nmove around"));
     connect(toolsEditCamAct, SIGNAL(triggered()), this, SLOT(slotToolsEditCam()));
 
     toolsTranslateAct = new QAction(QIcon(":/images/move.png"),tr("&Translate"), this);
-//    toolsTranslateAct->setShortcut(tr("Ctrl+T"));
     toolsTranslateAct->setShortcut(QKeySequence("Ctrl+T"));
     toolsTranslateAct->setStatusTip(tr("Translate"));
     toolsTranslateAct->setWhatsThis(tr("Translate\n\nTranslate Object"));
     connect(toolsTranslateAct, SIGNAL(triggered()), this, SLOT(slotToolsTranslate()));
 
     toolsRotateAct = new QAction(QIcon(":/images/rotate.png"), tr("&Rotate"), this);
-//    toolsRotateAct->setShortcut(tr("Ctrl+R"));
     toolsRotateAct->setShortcut(QKeySequence("Ctrl+R"));
     toolsRotateAct->setStatusTip(tr("Rotate"));
     toolsRotateAct->setWhatsThis(tr("Rotate\n\nRotate Object"));
     connect(toolsRotateAct, SIGNAL(triggered()), this, SLOT(slotToolsRotate()));
 
     toolsScaleAct = new QAction(QIcon(":/images/crop.png"), tr("&Scale"), this);
-//    toolsScaleAct->setShortcut(tr("Ctrl+A"));
     toolsScaleAct->setShortcut(QKeySequence("Ctrl+A"));
     toolsScaleAct->setStatusTip(tr("Scale"));
     toolsScaleAct->setWhatsThis(tr("Scale\n\nScale Object"));
     connect(toolsScaleAct, SIGNAL(triggered()), this, SLOT(slotToolsScale()));
 
     toolsPlayAct = new QAction(QIcon(":/images/run.png"), tr("&Play"), this);
-//    toolsPlayAct->setShortcut(tr("Ctrl+P"));
     toolsPlayAct->setShortcut(QKeySequence("Ctrl+P"));
     toolsPlayAct->setStatusTip(tr("Play"));
     toolsPlayAct->setWhatsThis(tr("Play\n\nswitch to Play mode"));
     connect(toolsPlayAct, SIGNAL(triggered()), this, SLOT(slotToolsPlay()));
 
     toolsPauseAct = new QAction(QIcon(":/images/redo.png"), tr("&Pause"), this);
-//    toolsPauseAct->setShortcut(tr("Ctrl+O"));
     toolsPauseAct->setShortcut(QKeySequence("Ctrl+O"));
     toolsPauseAct->setStatusTip(tr("Pause"));
     toolsPauseAct->setWhatsThis(tr("Pause\n\nswitch to Pause mode"));
     connect(toolsPauseAct, SIGNAL(triggered()), this, SLOT(slotToolsPause()));
 
     toolsStopAct = new QAction(QIcon(":/images/stop.png"), tr("&Stop"), this);
-//    toolsStopAct->setShortcut(tr("Ctrl+X"));
     toolsStopAct->setShortcut(QKeySequence("Ctrl+X"));
     toolsStopAct->setStatusTip(tr("Stop"));
     toolsStopAct->setWhatsThis(tr("Stop\n\nswitch to Stop mode"));
@@ -557,6 +546,7 @@ void MainWindow::createMenus()
     viewMenu = menuBar()->addMenu(tr("&View"));
     viewMenu->addAction(viewFullScreenAct);
     viewMenu->addAction(viewFrontScreenAct);
+    viewMenu->addAction(viewDebugAct);
 
     toolMenu = menuBar()->addMenu(tr("&Tool"));
     toolMenu->addAction(toolsEditCamAct);
@@ -800,7 +790,12 @@ void MainWindow::slotFullScreen()
 
 void MainWindow::slotFrontView()
 {
-      g_gl->viewCamera(NULL);
+      g_gl->switchCamera(NULL);
+}
+
+void MainWindow::slotDebugMode()
+{
+   g_debug = viewDebugAct->isChecked();
 }
 
 void MainWindow::slotToolsEditCam()
