@@ -68,6 +68,7 @@ private slots:
     void openRecentFile();
     void slotFullScreen();
     void slotFrontView();
+    void slotDebugMode();
     void slotToolsEditCam();
     void slotToolsTranslate();
     void slotToolsRotate();
@@ -143,6 +144,7 @@ private:
 //    QAction *viewStatusBarAct;
     QAction *viewFullScreenAct;
     QAction* viewFrontScreenAct;
+    QAction* viewDebugAct;
 
     QAction *helpAboutAppAct;
     QAction *helpaboutQtAct;
