@@ -858,6 +858,11 @@ void MediaPlayer::setBrightness(int val)
     m_videoWidget->setBrightness(val / qreal(SLIDER_RANGE));
 }
 
+void MediaPlayer::setFullScreen(bool val)
+{
+    m_videoWidget->setFullScreen(val);
+}
+
 void MediaPlayer::setContrast(int val)
 {
     m_videoWidget->setContrast(val / qreal(SLIDER_RANGE));
