@@ -159,7 +159,8 @@ void OpmlTree::parseFolderElement(const QDomElement &element, FolderListItem *pa
 
 void OpmlTree::updateDomElement(QTreeWidgetItem *item, int column)
 {
-	
+        Q_UNUSED(item);
+        Q_UNUSED(column);
 }
 void OpmlTree::getListView(QDomDocument *domdoc)
 {
@@ -210,7 +211,9 @@ void OpmlTree::buildDomTree( QDomElement *parentElement, FolderListItem *parentI
          ichild->text(1) == "CURSOR" ||
          ichild->text(1) == "SPL" ||
          ichild->text(1) == "JS" ||
+         ichild->text(1) == "PYTHON" ||
          ichild->text(1) == "SOUND" ||
+         ichild->text(1) == "MEDIA" ||
          ichild->text(1) == "GUI-TXT" ||
          ichild->text(1) == "GUI-INPUT" ||
          ichild->text(1) == "GUI-BUTTON" ||
@@ -243,7 +246,9 @@ void OpmlTree::buildDomTree( QDomElement *parentElement, FolderListItem *parentI
                 achild->text(1) == "CURSOR" ||
                 achild->text(1) == "SPL" ||
                 achild->text(1) == "JS" ||
+                achild->text(1) == "PYTHON" ||
                 achild->text(1) == "SOUND" ||
+                achild->text(1) == "MEDIA" ||
                 achild->text(1) == "GUI-TXT" ||
                 achild->text(1) == "GUI-INPUT" ||
                 achild->text(1) == "GUI-BUTTON" ||
@@ -321,9 +326,15 @@ void OpmlTree::initRMB()
     rmbAddQts = new QAction(tr("add JS"), this);
     rmbAddQts->setStatusTip(tr("add Java Script to scene"));
     connect(rmbAddQts, SIGNAL(triggered()), this, SLOT(slotAddQts()));
+    rmbAddPython = new QAction(tr("add PYTHON"), this);
+    rmbAddQts->setStatusTip(tr("add Python Script to scene"));
+    connect(rmbAddPython, SIGNAL(triggered()), this, SLOT(slotAddPython()));
     rmbAddSound = new QAction(tr("add SOUND"), this);
     rmbAddSound->setStatusTip(tr("add sound to scene"));
     connect(rmbAddSound, SIGNAL(triggered()), this, SLOT(slotAddSound()));
+    rmbAddMedia = new QAction(tr("add MEDIA"), this);
+    rmbAddMedia->setStatusTip(tr("add media to scene"));
+    connect(rmbAddMedia, SIGNAL(triggered()), this, SLOT(slotAddMedia()));
     rmbAddGUITXT = new QAction(tr("add GUI-Text"), this);
     rmbAddGUITXT->setStatusTip(tr("add GUI-Text to scene"));
     connect(rmbAddGUITXT, SIGNAL(triggered()), this, SLOT(slotAddGUITXT()));
@@ -371,7 +382,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -384,7 +397,7 @@ void OpmlTree::slotRMB( const QPoint & pos )
     {
        QMenu menu(this);
 //       menu.addAction(rmbAddScene);
-//       menu.addAction(rmbLoadObject);
+       menu.addAction(rmbLoadObject);
 //       menu.addAction(rmbAddBarrier);
 //       menu.addAction(rmbAddBody);
 //       menu.addAction(rmbAddFire);
@@ -399,7 +412,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -427,7 +442,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -455,7 +472,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -483,7 +502,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -511,7 +532,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -539,7 +562,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -567,7 +592,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -595,7 +622,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -623,7 +652,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
        menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
        menu.addAction(rmbAddSound);
+       menu.addAction(rmbAddMedia);
        menu.addAction(rmbAddGUITXT);
        menu.addAction(rmbAddGUIInput);
        menu.addAction(rmbAddGUIButton);
@@ -651,7 +682,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -679,7 +712,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -707,7 +742,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -735,7 +772,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -763,7 +802,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -791,7 +832,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -819,7 +862,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -847,7 +892,39 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
+//       menu.addAction(rmbAddGUITXT);
+//       menu.addAction(rmbAddGUIInput);
+//       menu.addAction(rmbAddGUIButton);
+//       menu.addAction(rmbAddGUIOSButton);
+//       menu.addAction(rmbAddLamp);
+       menu.addAction(rmbDelete);
+       menu.exec(mapToGlobal(pos));
+    }
+    if(item->text(1)=="MEDIA")
+    {
+       QMenu menu(this);
+//       menu.addAction(rmbAddScene);
+       menu.addAction(rmbLoadObject);
+//       menu.addAction(rmbAddBarrier);
+//       menu.addAction(rmbAddBody);
+       menu.addAction(rmbAddFire);
+       menu.addAction(rmbAddPartSys);
+       menu.addAction(rmbAddWaveSys);
+//       menu.addAction(rmbAddCamera);
+//       menu.addAction(rmbViewCamera);
+//       menu.addAction(rmbAddFog);
+//       menu.addAction(rmbAddPlayer);
+//       menu.addAction(rmbAddSky);
+//       menu.addAction(rmbAddShader);
+//       menu.addAction(rmbAddCursor);
+       menu.addAction(rmbAddSpl);
+       menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
+//       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -875,7 +952,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -901,8 +980,11 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddSky);
 //       menu.addAction(rmbAddShader);
 //       menu.addAction(rmbAddCursor);
+//       menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -930,7 +1012,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
 //       menu.addAction(rmbAddSpl);
 //       menu.addAction(rmbAddQts);
+//       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -958,7 +1042,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -986,7 +1072,9 @@ void OpmlTree::slotRMB( const QPoint & pos )
 //       menu.addAction(rmbAddCursor);
        menu.addAction(rmbAddSpl);
        menu.addAction(rmbAddQts);
+       menu.addAction(rmbAddPython);
 //       menu.addAction(rmbAddSound);
+//       menu.addAction(rmbAddMedia);
 //       menu.addAction(rmbAddGUITXT);
 //       menu.addAction(rmbAddGUIInput);
 //       menu.addAction(rmbAddGUIButton);
@@ -1185,6 +1273,17 @@ void OpmlTree::slotAddQts()
        }
 }
 
+void OpmlTree::slotAddPython()
+{
+    qWarning( "Slot AddPython  !" );
+
+       if(folderitem != NULL)
+       {
+          qWarning( "Object ok  !" );
+          ((FolderListItem *)folderitem)->addObject("PYTHON");
+       }
+}
+
 void OpmlTree::slotAddSound()
 {
     qWarning( "Slot AddSound  !" );
@@ -1196,6 +1295,17 @@ void OpmlTree::slotAddSound()
        }
 }
 
+void OpmlTree::slotAddMedia()
+{
+    qWarning( "Slot AddMedia  !" );
+
+       if(folderitem != NULL)
+       {
+          qWarning( "Object ok  !" );
+          ((FolderListItem *)folderitem)->addObject("MEDIA");
+       }
+}
+
 void OpmlTree::slotAddGUITXT()
 {
     qWarning( "Slot AddGUITXT  !" );
