@@ -379,6 +379,27 @@ PyObject* py_getRef( PyObject* self, PyObject* args )
     return Py_BuildValue("");
 }
 
+PyObject* py_getParentID( PyObject* self, PyObject* args )
+{
+    Q_UNUSED(self);
+
+    QcakeScriptApi *ScriptApi=QcakeScriptApi::theInstance();
+    // hh
+    int hh= 0;
+
+    if( PyArg_ParseTuple( args, "i", &hh)){
+        return Py_BuildValue( "i", ScriptApi->getParentID ( hh ) );
+    }else{
+        QString pyerr("pyError: getParentID: Parameter must ba a int !\n");
+        ErrorMsg errormsg(pyerr);
+    }
+/*
+    Py_INCREF( Py_None );
+    return Py_None;
+*/
+    return Py_BuildValue("");
+}
+
 PyObject* py_getJoystick( PyObject* self, PyObject* args )
 {
     Q_UNUSED(self);
@@ -841,6 +862,7 @@ PyMethodDef g_methodDefinitions[] =
     { "Rotate", py_Rotation, METH_VARARGS, "relativ Rotate h,p,r" },
     { "setPosition", py_setPosition, METH_VARARGS, "set Position" },
     { "getRef", py_getRef, METH_VARARGS, "get a Reference" },
+    { "getParentID", py_getParentID, METH_VARARGS, "get the parent Reference" },
     { "getJoystick", py_getJoystick, METH_VARARGS, "getJoystick" },
     { "getJoyButton", py_getJoyButton, METH_VARARGS, "get Joystick Button" },
     { "getMouse", py_getMouse, METH_VARARGS, "get Mouse Axis" },
@@ -861,14 +883,13 @@ PyMethodDef g_methodDefinitions[] =
     { "astarReadMapValue", py_astarReadMapValue, METH_VARARGS, "astar Read Map Value" },
     { "astarInit", py_astarInit, METH_VARARGS, "astar Init" },
     { "tmpobjInit", py_tmpobjInit, METH_VARARGS, "temp object Init" },
-//    { "setCallback", setCallback, METH_VARARGS, "Sets a call-back function in Python" },
     {NULL, NULL}
 };
 
 //-------- PythonEnv Singleton ---
 
  PythonEnv * PythonEnv::theInstancePtr = 0;
- PyObject *python_prg::update_pythonCallback = 0;
+ QHash<int, PyObject *> python_prg::pythonCallbackList;
 
 PythonEnv::PythonEnv (QObject *parent): QObject(parent)
 {
@@ -892,24 +913,25 @@ PythonEnv * PythonEnv::theInstance(QObject *parent) {
 
 void PythonEnv::Init ()
 { 
-    Py_Initialize();  // ? should this  be done in a singleton obj ??
+    Py_Initialize();
     // Define our custom module called "QCakeApi"
     PyImport_AddModule( "QCakeApi" );
     Py_InitModule( "QCakeApi", g_methodDefinitions );
+    // Get a reference to the main module.
+    main_module = PyImport_AddModule("__main__");
+    main_dict = PyModule_GetDict(main_module);
 }
 
 //---------------------------------
 
-python_prg::python_prg(const QString & program)
+python_prg::python_prg(const QString & program, const int thisid)
  : scriptPrg()
 {
     prgname = program;
-    update_pythonCallback= NULL;
+    qcid = thisid;
     // Setup Python to be embedded...
     PythonEnv *mypython=PythonEnv::theInstance();
-    // Access the "__main__" module and its name-space dictionary.
-    pMainModule     = PyImport_AddModule( "__main__" );
-    pMainDictionary = PyModule_GetDict( pMainModule );
+    main_dict_copy = PyDict_Copy(mypython->main_dict);
 }
 
 
@@ -926,6 +948,11 @@ int python_prg::compile(void)
 int python_prg::run(void)
 {
   if(on==1){
+    // Initialize a global variable
+    QString globvar;
+    globvar = QString("QCakeID = %1").arg(qcid);
+    PyRun_String(globvar.toAscii().constData() , Py_file_input,
+                      main_dict_copy, main_dict_copy );
     // load the standard python qcake library
     if(runFile(g_prjpath + "/data/python_stdlib.py")){
       return 1;
@@ -946,7 +973,7 @@ int python_prg::runFile(const QString &prgfile)
   char *myprg=strdup(srcprg.toAscii().constData());
   PyObject *p   = NULL;
   p=PyRun_String( myprg, Py_file_input,
-                      pMainDictionary, pMainDictionary );
+                      main_dict_copy, main_dict_copy );
   if (p) {
 
   } else {
@@ -959,17 +986,18 @@ int python_prg::runFile(const QString &prgfile)
 
 void python_prg::update(void)
 {
-  if(on==1){
-    if( update_pythonCallback ){
+    if(on==1){
         int nArg1 = 123;
         PyObject *pArgList = Py_BuildValue( "(i)", nArg1 );
-        PyObject *pResult  = PyEval_CallObject( update_pythonCallback, pArgList );
+        PyObject *pResult = NULL;
+        if(pythonCallbackList.contains(qcid)){
+            pResult  = PyEval_CallObject( pythonCallbackList[qcid], pArgList );
+        }
         Py_DECREF( pArgList );
         if( pResult != NULL ){
             Py_DECREF( pResult );
         }
     }
-  }
 }
 
 PyObject* python_prg::setCallback( PyObject* self, PyObject* args )
@@ -977,16 +1005,17 @@ PyObject* python_prg::setCallback( PyObject* self, PyObject* args )
     Q_UNUSED(self);
 
     PyObject *temp   = NULL;
-
-    if( PyArg_ParseTuple( args, "O", &temp )){
+    int pyid=0;
+    if( PyArg_ParseTuple( args, "Oi", &temp, &pyid)){
         if( !PyCallable_Check( temp )){
             QString pyerr("pyError: setCallback: parameter must be callable\n");
             ErrorMsg errormsg(pyerr);
             return Py_BuildValue("");
         }
         Py_XINCREF( temp );                   // Ref the new call-back
-        Py_XDECREF( update_pythonCallback );  // Unref the previous call-back
-        update_pythonCallback = temp;         // Cache the new call-back
+ //       Py_XDECREF( update_pythonCallback );  // Unref the previous call-back
+ //       update_pythonCallback = temp;         // Cache the new call-back
+        pythonCallbackList[pyid]= temp;
     }
 /*
     Py_INCREF( Py_None );
