@@ -18,6 +18,8 @@ class PythonEnv : public QObject
 public:
 
   static PythonEnv *theInstance(QObject *parent=0);
+  PyObject *main_module;
+  PyObject *main_dict;
 
    PythonEnv (QObject *parent=0);
    ~PythonEnv ();
@@ -32,7 +34,7 @@ private:
 class python_prg : public scriptPrg
 {
 public:
-    python_prg(const QString & program);
+    python_prg(const QString & program, const int thisid);
     ~python_prg();
 
     int compile(void);
@@ -41,7 +43,7 @@ public:
     static PyObject* setCallback( PyObject* self, PyObject* args );
 
 private:
-    static PyObject *update_pythonCallback;
+   static QHash<int, PyObject *> pythonCallbackList;
 
 protected:
     int runFile(const QString &prgfile);
@@ -50,7 +52,8 @@ protected:
     QcakeScriptApi *ScriptApi;
     QString  prgname;
     PyObject *pMainModule;
-    PyObject *pMainDictionary;
+    PyObject *main_dict_copy;
+    int qcid;
 };
 
 #endif
