@@ -17,14 +17,20 @@
 #include "messages.hpp"
 
 
-qtscriptPrg::qtscriptPrg(const QString & program)
+qtscriptPrg::qtscriptPrg(const QString & program , const int thisid)
  : scriptPrg()
 {
+     isupdate=1;
      prgname = program;
+#ifdef USE_SCRIPT_DEBUGGER
+    debugger.attachTo(&engine);
+    QMainWindow *debugWindow = debugger.standardWindow();
+    debugWindow->resize(1024, 640);
+#endif
      ScriptApi=QcakeScriptApi::theInstance();
      QScriptValue objectValue = engine.newQObject(ScriptApi);
      engine.globalObject().setProperty("QCakeApi", objectValue);
-//     engine.setProcessEventsInterval ( 100 );  // dont work for me ??
+     engine.globalObject().setProperty("QCakeID", thisid);
 }
 
 
@@ -41,21 +47,30 @@ int qtscriptPrg::run(void)
 {
  if(on==1){
     // load the standard js qcake library
-    if(runFile(g_prjpath + "/data/js_stdlib.js")){
+    if(runFile(g_prjpath + "/data/js_stdlib.js","js_stdlib.js", FALSE)){
         return 1;
     }
-    if(runFile(prgname)){
+    QFileInfo filename(prgname);
+    if(runFile(prgname, filename.fileName(), g_debug)){
         return 1;
     }
+    QScriptValue handler = engine.evaluate("function() { update(); }");
+    qScriptConnect(this, SIGNAL(scr_update()), QScriptValue(), handler);
+    isupdate=0;
   }
   return 0;
 }
 
-int qtscriptPrg::runFile(const QString &prgfile)
+int qtscriptPrg::runFile(const QString &prgfile, const QString &name, bool debug)
 {
   QFile scriptFile(prgfile);
   scriptFile.open(QIODevice::ReadOnly);
-  QScriptValue result = engine.evaluate(scriptFile.readAll());
+  #ifdef USE_SCRIPT_DEBUGGER
+  if(debug == TRUE) {
+    debugger.action(QScriptEngineDebugger::InterruptAction)->trigger();
+  }
+#endif
+  QScriptValue result = engine.evaluate(scriptFile.readAll(),name);
   if (engine.hasUncaughtException()) {
      int line = engine.uncaughtExceptionLineNumber();
      qDebug() << prgfile << ":uncaught exception at line " << line << ":" << result.toString();
@@ -72,14 +87,10 @@ int qtscriptPrg::runFile(const QString &prgfile)
 void qtscriptPrg::update(void)
 {
  if(on==1){
-   QScriptValue result = engine.evaluate("update()");
-   if (engine.hasUncaughtException()) {
-      int line = engine.uncaughtExceptionLineNumber();
-      qDebug() << prgname << ":uncaught exception at line " << line << ":" << result.toString();
-      QString msg;
-      QTextStream(&msg) << prgname << ":uncaught exception at line " << line << ":" << result.toString() << ".  Script stopped.\n";
-      ErrorMsg errormsg(msg);
-      TurnOff();
-   }
+     isupdate++;
+     if(isupdate == 1){
+         emit scr_update();
+     }
+     isupdate--;
  }
 }
