@@ -17,31 +17,32 @@
 #ifndef QTSCRIPT_PRG_H
 #define QTSCRIPT_PRG_H
 
-#include <QtScript/QtScript>
+#include <QtScript>
 
 #include "scripting.hpp"
 #include "scriptprg.hpp"
 
+#ifdef USE_SCRIPT_DEBUGGER
+#include <QScriptEngineDebugger>
+#endif
 
 class qtscriptPrg : public scriptPrg
 {
 public:
-    qtscriptPrg(const QString & program);
-
+    qtscriptPrg(const QString & program , const int thisid);
     ~qtscriptPrg();
-
-     int compile(void);
-     int run(void);
-     void update(void);
+    int compile(void);
+    int run(void);
+    void update(void);
 
 protected:
-
-  int runFile(const QString &prgfile);
-
+  int runFile(const QString &prgfile, const QString &name, bool debug);
   QScriptEngine engine;
+#ifdef USE_SCRIPT_DEBUGGER
+  QScriptEngineDebugger debugger;
+#endif
   QcakeScriptApi *ScriptApi;
   QString  prgname;
-
 };
 
 #endif
