@@ -267,6 +267,11 @@ int QcakeScriptApi::getRef ( int id )
   return m -> getHandle () ;
 }
 
+int QcakeScriptApi::getParentID ( int id )
+{
+    return(splaModel::getParentID(id ,inititem));
+}
+
 int QcakeScriptApi::getMouse ( int a )
 {
   int value = 0;
