@@ -36,10 +36,13 @@ public slots:
     void slot_update(const QString &);
     void slot_compile(void);
     void slot_run(void);
+signals:
+    void	scr_update();
 
 protected:
   int on;
   int enable;
+  int isupdate;
 };
 
 #endif
