@@ -20,7 +20,7 @@
 #include "GLee.h"
 #include "shader.hpp"
 #include <stdio.h>
-#include <malloc.h>
+//#include <malloc.h>
 #include <stdlib.h>
 
 #include <fcntl.h>
@@ -110,7 +110,8 @@ GLint shader::GetVariable(char * strVariable)
   if(!p)
      return -1;
 
-  return glGetUniformLocationARB(p, strVariable);
+//  return glGetUniformLocationARB(p, strVariable);
+    return 0;
 }
 
 
@@ -134,17 +135,22 @@ void shader::Release()
   // If our program object pointer is valid, free it
 
   if(v){
-     glDetachObjectARB(p, v);
-     glDeleteObjectARB(v);
+      glDetachShader(p, v);
+      glDeleteShader(v);
+//     glDetachObjectARB(p, v);
+//     glDeleteObjectARB(v);
      v = 0;
   }
   if(f){
-     glDetachObjectARB(p, f);
-     glDeleteObjectARB(f);
+      glDetachShader(p, f);
+      glDeleteShader(f);
+//     glDetachObjectARB(p, f);
+//     glDeleteObjectARB(f);
      f = 0;
   }
   if(p){
-     glDeleteObjectARB(p);
+      glDeleteProgram(p);
+//     glDeleteObjectARB(p);
      p = 0;
   }
 }
@@ -156,11 +162,11 @@ char * shader::GetInfoLog(GLuint handle)                     // beta status
   char filename[256];
   filename[0]=0;
   if(handle == v) strncpy(filename,VerFileName,255);
-  if(handle == v) strncpy(filename,FraFileName,255);
-  glGetObjectParameterivARB(handle, GL_OBJECT_INFO_LOG_LENGTH_ARB , &blen);
+  if(handle == f) strncpy(filename,FraFileName,255);
+//  glGetObjectParameterivARB(handle, GL_OBJECT_INFO_LOG_LENGTH_ARB , &blen);
   if (blen > 1){
      GLcharARB* infoLog = new GLcharARB[blen];       
-     glGetInfoLogARB( handle, blen, &slen, infoLog );
+//     glGetInfoLogARB( handle, blen, &slen, infoLog );
      qWarning("Shader: ");
      qWarning(filename);
      qWarning(infoLog);
