@@ -277,6 +277,18 @@ static struct spl_node *my_getRef ( struct spl_task *task, void *data )
   }
 }
 
+static struct spl_node *my_getParentID ( struct spl_task *task, void *data )
+{
+  if ( spl_clib_get_argc(task) != 1 ){
+    spl_report(SPL_REPORT_RUNTIME, task,"my_getParentID: Parameter must ba a int !\n" ) ;
+    ((splPrg *)data)->TurnOff();
+    return 0 ;
+  } else {
+    return SPL_NEW_INT(((splPrg *)data)->ScriptApi->getParentID ( spl_clib_get_int(task)));
+  }
+}
+
+
 static struct spl_node *my_getJoystick ( struct spl_task *task, void *data )
 {
   if ( spl_clib_get_argc(task) != 2 ){
@@ -547,7 +559,7 @@ static struct spl_node *my_tmpobjInit ( struct spl_task *task, void *data )
 }
 
 //**************************************************************** 
-splPrg::splPrg(const char *prg)
+splPrg::splPrg(const char *prg , const int thisid)
 :scriptPrg()
  {
      ScriptApi=QcakeScriptApi::theInstance();
@@ -585,6 +597,7 @@ splPrg::splPrg(const char *prg)
      spl_clib_reg(vm, (char *)"Rotate"       , my_Rotation    ,  this);
      spl_clib_reg(vm, (char *)"setPosition"  , my_setPosition ,  this);
      spl_clib_reg(vm, (char *)"getRef"       , my_getRef      ,  this);
+     spl_clib_reg(vm, (char *)"getParentID"  , my_getParentID ,  this);
      spl_clib_reg(vm, (char *)"getMouse"     , my_getMouse    ,  this);
      spl_clib_reg(vm, (char *)"get3DMouse"   , my_get3DMouse  ,  this);
      spl_clib_reg(vm, (char *)"getMouseButton"     , my_getMouseButton    ,  this);
@@ -603,7 +616,12 @@ splPrg::splPrg(const char *prg)
      spl_clib_reg(vm, (char *)"astarReadMapValue" , my_astarReadMapValue  ,  this);
      spl_clib_reg(vm, (char *)"astarInit"    , my_astarInit   ,  this);
      spl_clib_reg(vm, (char *)"tmpobjInit"   , my_tmpobjInit  ,  this);
-    
+
+     // register global variables QCakeID
+     // spl_vm member root value erzeugen spl_reate vm_root
+     // see mod_time convert_tm_to_node but use vm_root context and not the node
+     spl_create(task, vm->root, "QCakeID",   SPL_NEW_INT(thisid),   SPL_CREATE_LOCAL);
+
      // load the standard spl qcake library
      QString spl_stdlib_file = g_prjpath + "/data/spl_stdlib.spl";
      qDebug() << spl_stdlib_file;
