@@ -38,7 +38,7 @@ class splPrg : public scriptPrg
   Q_OBJECT
 
    public:
-     splPrg(const char *prg);
+     splPrg(const char *prg , const int thisid);
 
      int compile(void);
      void update(void);
