@@ -26,7 +26,7 @@ splaModel::splaModel ( const int id ,FolderListItem *item)
     handle = splaModel::g_Models.indexOf(this);
     if(id != 0 && item != NULL){
       if((miditem = item->search_id((FolderListItem *)item->treeWidget()->invisibleRootItem(),id)) == NULL){
-          qWarning (  "scripting: There is no such 3D Object as '%d'\n", id ) ;
+          qWarning (  "scripting: There is no such Object as '%d'\n", id ) ;
       } else {
         update ( 0 );
       }
@@ -43,6 +43,22 @@ splaModel::~splaModel(void)
 
 int splaModel::getHandle () const { return handle ; }
 
+int splaModel::getParentID (const int id, FolderListItem *item)
+{
+    FolderListItem *iditem;
+    FolderListItem *parentitem;
+
+    if(id != 0 && item != NULL){
+        if((iditem = item->search_id((FolderListItem *)item->treeWidget()->invisibleRootItem(),id)) == NULL){
+          qWarning (  "scripting: There is no such Object as '%d'\n", id ) ;
+        } else {
+          parentitem = (FolderListItem *) iditem->parent();
+          return(parentitem->GetValue("tmpid").toInt());
+        }
+    }
+    return 0;
+}
+
 void splaModel::playSound () { play=1; }
 void splaModel::stopSound () { play=2; }
 
@@ -57,129 +73,21 @@ void splaModel::setPosition ( float x, float y, float z, float h, float p, float
 {
     sgSetCoord ( &pos, x, y, z, h, p, r ) ;
     updateme=1;
+    update ( 0 );
 }
 
 void splaModel::update ( double dt )
 {
     Q_UNUSED(dt);
 
-    sgMat4 m ;
-
     ph_mutex.lock();
     if(miditem != NULL ){
-      // this code is possible to move to the listviews.cpp
-      if(miditem->text(1) == "OBJECT"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos,miditem->GetValue("scax").toFloat(),miditem->GetValue("scay").toFloat(),miditem->GetValue("scaz").toFloat() ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
+        if(updateme==1){
+            miditem->update( &pos );
         }
-      }
-      if(miditem->text(1) == "TMPOBJ"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos,miditem->GetValue("scax").toFloat(),miditem->GetValue("scay").toFloat(),miditem->GetValue("scaz").toFloat() ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
-        }
-      }
-      if(miditem->text(1) == "FIRE"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
-        }
-      }
-      if(miditem->text(1) == "WAVESYS"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
-        }
-      }
-      if(miditem->text(1) == "PARTSYS"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
-        }
-      }
-      if(miditem->text(1) == "CAMERA"){
-        if(miditem->objtrans != NULL){
-          if(updateme==1){
-            miditem->objtrans->setTransform ( & pos ) ;
-          }
-          miditem->objtrans->getTransform ( m ) ;
-          sgSetCoord  ( &pos, m ) ;
-        }
-      }
-      if(miditem->text(1) == "BARRIER"){
-        if(miditem->barrier != NULL){
-          if(updateme==1){
-            miditem->barrier->pos.xyz[0] = pos.xyz[0];
-            miditem->barrier->pos.xyz[1] = pos.xyz[1];
-            miditem->barrier->pos.xyz[2] = pos.xyz[2];
-
-            miditem->barrier->pos.hpr[0] = pos.hpr[0];
-            miditem->barrier->pos.hpr[1] = pos.hpr[1];
-            miditem->barrier->pos.hpr[2] = pos.hpr[2];
-            miditem->barrier->setPosition ();
-          }
-          miditem->barrier->getPosition (&pos);
-        }
-      }
-      if(miditem->text(1) == "PLAYER"){
-        if( miditem->player != NULL){
-          if(updateme==1){
-            miditem->player->pos.xyz[0] = pos.xyz[0];
-            miditem->player->pos.xyz[1] = pos.xyz[1];
-            miditem->player->pos.xyz[2] = pos.xyz[2];
-
-            miditem->player->pos.hpr[0] = pos.hpr[0];
-            miditem->player->pos.hpr[1] = pos.hpr[1];
-            miditem->player->pos.hpr[2] = pos.hpr[2];
-            miditem->player->SetPosition ();
-          }
-          miditem->player->GetPosition (&pos);
-        }
-      }
-      if(miditem->text(1) == "BODY"){
-        if(miditem->body != NULL){
-          if(updateme==1){
-            miditem->body->pos.xyz[0] = pos.xyz[0];
-            miditem->body->pos.xyz[1] = pos.xyz[1];
-            miditem->body->pos.xyz[2] = pos.xyz[2];
-
-            miditem->body->pos.hpr[0] = pos.hpr[0];
-            miditem->body->pos.hpr[1] = pos.hpr[1];
-            miditem->body->pos.hpr[2] = pos.hpr[2];
-            miditem->body->setPosition ();
-          }
-          miditem->body->getPosition (&pos);        
-        }
-      }
-      if(miditem->text(1) == "LAMP"){
-
-      }
-      if(miditem->text(1) == "CURSOR"){
-        if(miditem->cursor != NULL){
-          miditem->cursor->getPosition(&pos);
-        }
-      }
+        miditem->getPosition (&pos);
       if(miditem->text(1) == "SOUND"){
         if(miditem->sound != NULL){
-          if(updateme==1){
-             miditem->sound->setPosition(pos.xyz[0], pos.xyz[1], pos.xyz[2]);
-          }
           if(play==1){
             miditem->sound->Play();
             play=0;
@@ -192,9 +100,6 @@ void splaModel::update ( double dt )
       }
       if(miditem->text(1) == "MEDIA"){
         if(miditem->sound != NULL){
-          if(updateme==1){
-             miditem->sound->setPosition(pos.xyz[0], pos.xyz[1], pos.xyz[2]);
-          }
           if(play==1){
             miditem->sound->Play();
             play=0;
@@ -376,28 +281,11 @@ void splaModel::setRotation ( float h, float p, float r )
 }
 
 void splaModel::Rotation ( float h, float p, float r )
-{
-    sgMat4 m ;
-    sgMat4 mh ;
-    
+{    
       ph_mutex.lock();
-      if(miditem->text(1) == "OBJECT"){
-        sgMakeCoordMat4 ( mh, 0, 0, 0, h, p, r ) ;
-        miditem->objtrans->getTransform ( m ) ;
-        sgPreMultMat4  ( m, mh ) ;
-        miditem->objtrans->setTransform ( m ) ;    
-      }
-      if(miditem->text(1) == "TMPOBJ"){
-        sgMakeCoordMat4 ( mh, 0, 0, 0, h, p, r ) ;
-        miditem->objtrans->getTransform ( m ) ;
-        sgPreMultMat4  ( m, mh ) ;
-        miditem->objtrans->setTransform ( m ) ;    
-      }
-      if(miditem->text(1) == "BODY"){
-          miditem->body->Rotation(h,p,r);
-      }
-      if(miditem->text(1) == "BARRIER"){
-          miditem->barrier->setRotation(h,p,r);
+      if(miditem != NULL ){
+          miditem->Rotation(h, p, r);
+          update ( 0 );
       }
       ph_mutex.unlock();
 }
