@@ -95,6 +95,24 @@ void TriBarrier::buildTriMeshData(const char *file)
 #endif
 }
 
+void TriBarrier::setScale(const float sx, const float sy, const float sz )
+{
+   long a;
+
+   for(a=0;a<VertexCount;a++){
+     VerticesScale[a][0] = Vertices[a][0] * sx;
+     VerticesScale[a][1] = Vertices[a][1] * sy;
+     VerticesScale[a][2] = Vertices[a][2] * sz;
+   }
+#ifdef dDOUBLE
+    dGeomTriMeshDataBuildSimple(data,(dReal *)VerticesScale,VertexCount,Indices,IndexCount);
+#endif
+#ifdef dSINGLE
+    dGeomTriMeshDataBuildSingle(data, (float *)&VerticesScale[0], 3 * sizeof(float), VertexCount, (int*)&Indices[0], IndexCount, 3 * sizeof(int));
+#endif
+    dGeomTriMeshSetData (TriMesh, data);
+}
+
 void TriBarrier::Print()
 {
    long a;
@@ -163,9 +181,9 @@ void TriBarrier::SetPosition ()
   dMatrix3 odR;
 
   dGeomSetPosition (TriMesh,pos.xyz[0],pos.xyz[1],pos.xyz[2]);
-  dRFromEulerAngles(odR,-pos.hpr[1] * SG_DEGREES_TO_RADIANS
-                      ,-pos.hpr[2] * SG_DEGREES_TO_RADIANS
-                      ,-pos.hpr[0] * SG_DEGREES_TO_RADIANS);
+  dRFromEulerAngles(odR,-pos.hpr[0] * SG_DEGREES_TO_RADIANS
+                      ,-pos.hpr[1] * SG_DEGREES_TO_RADIANS
+                      ,-pos.hpr[2] * SG_DEGREES_TO_RADIANS);
   dGeomSetRotation (TriMesh,odR);
 }
 
