@@ -35,6 +35,7 @@ class TriBarrier
      void   update();
      void   setTransform (ssgTransform *objtrans, const dReal pos[3], const dReal R[12],dVector3 dxyz);
      void   SetPosition ();
+     void   setScale(const float sx, const float sy, const float sz );
      void   Print ();
      void   GetPosition ( sgCoord  *bodypos );
      ~TriBarrier(void);
@@ -53,11 +54,14 @@ protected:
    long IndexCount;
 #ifdef dDOUBLE
    dVector3 Vertices[MAXVERTEX];
+   dVector3 VerticesScale[MAXVERTEX];
 #endif
 #ifdef dSINGLE
    float Vertices[MAXVERTEX][3];
+   float VerticesScale[MAXVERTEX][3];
 #endif
    int Indices[MAXINDEX];
+   dReal scale[3];
 };
 
 #endif
